
/**
 * Copyright 2013 Peergreen S.A.S.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ow2.util.scan.api.configurator;

import java.lang.annotation.ElementType;
import java.util.Collection;
import java.util.Map;

import org.ow2.util.scan.api.IAnnotationVisitor;
import org.ow2.util.scan.api.metadata.structures.IAnnotation;

/**
 * Configurator for annotations processing
 * @author Florent Benoit
 */
public interface IAnnotationConfigurator {

    /**
     * Add visitor for the class
     * @param annotationVisitors the visitors to be launched on the class
     */
    void registerAnnotationVisitor(IAnnotationVisitor<?> annotationVisitor);

    /**
     * Add visitors for the class
     * @param annotationVisitors the visitors to be launched on the class
     */
    void registerAnnotationVisitors(Collection<IAnnotationVisitor<?>> annotationVisitors);


    /**
     * @param annotation signature of annotation
     * @return the visitor in the map or empty visitor
     */
    IAnnotationVisitor<?> getAnnotationVisitor(final IAnnotation annotation, ElementType elementType);

    /**
     * Filter all the given annotations by selecting the name for which they're registered and the type
     * @param elementType the given element type
     * @return
     */
    Map<String, IAnnotationVisitor<?>> filter(ElementType elementType);
}
