/**
 * Copyright 2006-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.scan.api.configurator.basic;

import org.ow2.util.scan.api.IScannerResult;
import org.ow2.util.scan.api.configurator.IFieldConfigurator;
import org.ow2.util.scan.api.metadata.IFieldMetadata;

/**
 * FieldMetadataConfigurator is a configurator of field specific to FieldMetata.
 * @author Gael Lalire
 */
public class FieldMetadataConfigurator extends BasicConfigurator implements IFieldConfigurator {

    /**
     * the field metadata.
     */
    private final IFieldMetadata fieldMetadata;

    /**
     * @return the field metadata
     */
    protected IFieldMetadata getFieldMetadata() {
        return fieldMetadata;
    }

    /**
     * Construtor.
     * @param fieldMetadata the field metadata
     */
    public FieldMetadataConfigurator(final IFieldMetadata fieldMetadata) {
        this.fieldMetadata = fieldMetadata;
    }



    /**
     * Add the field metadata to his class metadata when configuration ended.
     * @param referencedClasses you may fill this set with class referenced in current metadata
     */
    @Override
    public void configurationComplete(final IScannerResult scannerResult) {
        super.configurationComplete(scannerResult);
        fieldMetadata.getClassMetadata().addFieldMetadata(fieldMetadata);

    }

}
