/**
 * Copyright 2013 Peergreen S.A.S.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ow2.util.scan.api.configurator.basic;

import java.util.ArrayList;
import java.util.List;

import org.ow2.util.scan.api.configurator.IAnnotationConfigurator;
import org.ow2.util.scan.api.configurator.IClassConfigurator;
import org.ow2.util.scan.api.configurator.ISessionConfigurator;
import org.ow2.util.scan.api.configurator.IViewConfigurator;
import org.ow2.util.scan.api.metadata.IClassMetadata;

/**
 * Defines a session configurator that allows to scan/parse all metadata of an archive
 * @author Florent Benoit
 */
public class SessionConfigurator implements ISessionConfigurator {

    /**
     * List of view configurators that allows to plug views for the metadata
     */
    private final List<IViewConfigurator> viewConfigurators;

    /**
     * List of annotation configurators that allows to plug annotation visitors for the metadata
     */
    private final List<IAnnotationConfigurator> annotationConfigurators;

    public SessionConfigurator() {
        this.viewConfigurators = new ArrayList<>();
        this.annotationConfigurators = new ArrayList<>();
    }


    @Override
    public IClassConfigurator createClassConfigurator(IClassMetadata classMetadata) {
        return new ClassMetadataConfigurator(classMetadata);
    }

    @Override
    public List<IAnnotationConfigurator> getAnnotationConfigurators() {
        return annotationConfigurators;
    }


    @Override
    public List<IViewConfigurator> getViewConfigurators() {
        return viewConfigurators;
    }

}
