/**
 * Copyright 2013 Peergreen S.A.S.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ow2.util.scan.api.configurator.basic;

import java.lang.annotation.ElementType;
import java.util.HashMap;
import java.util.Map;

import org.ow2.util.scan.api.IMetadataViewFactory;
import org.ow2.util.scan.api.annotation.ViewTarget;
import org.ow2.util.scan.api.configurator.IViewConfigurator;

public class ViewConfigurator implements IViewConfigurator {

    private final Map<ElementType, Map<Class<?>, IMetadataViewFactory<?>>> views;


    public ViewConfigurator() {
        this.views = new HashMap<>();
        for (ElementType elementType : ElementType.values()) {
            this.views.put(elementType, new HashMap<Class<?>, IMetadataViewFactory<?>>());
        }
    }


    @Override
    public <View> void registerView(Class<View> clazz, IMetadataViewFactory<View> metadataView) {
        ViewTarget viewTarget = metadataView.getClass().getAnnotation(ViewTarget.class);
        if (viewTarget == null) {
            throw new IllegalArgumentException("Invalid view, no @ViewTarget annotation");
        }
        for (ElementType elementType : viewTarget.value()) {
            views.get(elementType).put(clazz, metadataView);
        }
    }


    @SuppressWarnings("unchecked")
    @Override
    public <View> IMetadataViewFactory<View> getView(ElementType elementType, Class<View> clazz) {
        return (IMetadataViewFactory<View>) views.get(elementType).get(clazz);
    }


}
