/**
 * Copyright 2006-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.scan.api.metadata;

import java.io.Serializable;
import java.lang.reflect.Method;

import org.ow2.util.scan.api.metadata.structures.IMethod;

/**
 * Interface of a method metadata.
 * @author Gael Lalire
 */
public interface IMethodMetadata extends IMetadata, Serializable {

    /**
     * @return JMethod object
     */
    IMethod getJMethod();

    /**
     * Sets the JMethod object (for changing some data).
     * @param jMethod the given JMethod object
     */
    void setJMethod(final IMethod jMethod);

    /**
     * @return parent metadata (class)
     */
    IClassMetadata getClassMetadata();

    /**
     * @param classMetadata parent metadata (class)
     */
    void setClassMetadata(final IClassMetadata classMetadata);

    /**
     * Allow to get a reflect method from its metadata.
     * @param jMethod the method info
     * @param clazz the class that is containing the method
     * @return an instance of the method
     */
    Method getReflectMethod(final Class<?> clazz);

    String[] getParametersClassName();

}
