/**
 * Copyright 2006-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.scan.api.visitor;

import org.ow2.util.scan.api.IAnnotationVisitor;
import org.ow2.util.scan.api.IAnnotationVisitorContext;

/**
 * DefaultAnnotationVisitor.
 * @author Gael Lalire
 */
public abstract class DefaultAnnotationVisitor<T> implements IAnnotationVisitor<T> {

    /**
     * Empty visit method.
     * @param name annotation name
     * @param value annotation value
     */
    @Override
    public void visit(final String name, final Object value, IAnnotationVisitorContext<T> annotationVisitorContext) {
    }

    /**
     * Empty visit annotation method.
     * @param name annotation name
     * @param desc annotation desc
     * @return itself
     */
    @Override
    public IAnnotationVisitor<T> visitAnnotation(final String name, final String desc, IAnnotationVisitorContext<T> annotationVisitorContext) {
        return this;
    }

    /**
     * Empty visit array method.
     * @param name array name
     * @return itself
     */
    @Override
    public IAnnotationVisitor<T> visitArray(final String name, IAnnotationVisitorContext<T> annotationVisitorContext) {
        return this;
    }

    /**
     * Empty visitEnd method.
     */
    @Override
    public void visitEnd(IAnnotationVisitorContext<T> annotationVisitorContext) {
    }

    /**
     * Empty visit enumeration method.
     * @param name enumeration name
     * @param desc enumeration desc
     * @param value enumeration value
     */
    @Override
    public void visitEnum(final String name, final String desc, final String value, IAnnotationVisitorContext<T> annotationVisitorContext) {
    }

    @Override
    public abstract T buildInstance();


}
