/**
 * Copyright 2013 Peergreen S.A.S.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ow2.util.scan.impl;

import org.ow2.util.scan.api.IAnnotationVisitor;
import org.ow2.util.scan.api.IAnnotationVisitorContext;
import org.ow2.util.scan.api.metadata.IMetadata;
import org.ow2.util.scan.api.metadata.structures.IMember;

public class BasicVisitorContext<T> implements IAnnotationVisitorContext<T> {

    private T localInstance;

    public final IMetadata metadata;


    private final IAnnotationVisitor<T> annotationVisitor;


    public BasicVisitorContext(IAnnotationVisitor<T> annotationVisitor, IMetadata metadata) {
        this.annotationVisitor = annotationVisitor;
        this.metadata = metadata;
    }

    @SuppressWarnings({ "unchecked", "rawtypes" })
    @Override
    public void set(T instance) {
        Class<?>[] interfaces = instance.getClass().getInterfaces();
        for (Class itf : interfaces) {
            metadata.set(itf, itf.cast(instance));
        }
        // No interface, register it without interfaces
        if (interfaces.length == 0) {
            metadata.set((Class<T>) instance.getClass(), instance);
        }
    }

    @Override
    public <U> U get(Class<U> clazz) {
        return metadata.get(clazz);
    }

    @Override
    public <U> void set(Class<U> clazz, U instance) {
        metadata.set(clazz, instance);
    }

    @Override
    public void setLocal(T var) {
        this.localInstance = var;
    }

    @Override
    public T getLocal() {
        if (this.localInstance == null) {
            this.localInstance = annotationVisitor.buildInstance();
        }
        return localInstance;
    }

    @Override
    public IMember getVisitedMember() {
        return metadata.getMember();
    }

    @Override
    public T getProperty(String name) {
        return metadata.getProperty(name);
    }

    @Override
    public void setProperty(String name, T value) {
        metadata.setProperty(name, value);
    }

    @Override
    public <U> U getView(Class<U> clazz) {
        return metadata.as(clazz);
    }

}
