/*
 * OW2 Utilities
 * Copyright (C) 2009-2012 Bull S.A.S.
 * Contact: utilities@ow2.org
 *
 * Licensed  under the  Apache License,  Version 2.0  (the "License");
 * you may not use  this file  except in  compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed  under the  License is distributed on an "AS IS" BASIS,
 * WITHOUT  WARRANTIES OR CONDITIONS  OF ANY KIND, either  express  or
 * implied.
 *
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.scan.impl.osgi;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceRegistration;
import org.ow2.util.scan.api.IScanner;
import org.ow2.util.scan.impl.ASMScannerImpl;

/**
 * A {@link ScannerActivator} registers (respectively unregisters) an {@link ASMScannerImpl} as an {@link IScanner} service at bundle
 * startup (respectively stop).
 *
 * @author Loic Albertin
 */
public class ScannerActivator implements BundleActivator {
    private ServiceRegistration<IScanner> scannerServiceRegistration;

    /**
     * {@inheritDoc}
     */
    @Override
    public void start(BundleContext context) throws Exception {
        scannerServiceRegistration = context.registerService(IScanner.class, new ASMScannerImpl(), null);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void stop(BundleContext context) throws Exception {
        scannerServiceRegistration.unregister();
    }
}
